 % Returns the baseline settings and parameters structures
function [parameters, settings] = baseline_joint_endogenous_settings()
    %% Parameters and model variations.
    parameters.lambda_l = 0.533074;
    parameters.lambda_h = 1.12766;
    parameters.chi = .00106 * 2;
    parameters.rho = .06;
    parameters.Lambda = 0; %The CRRA parameter    
    parameters.psi = 1;
    parameters.eta = 0.0;
    parameters.z_bar = 5.0;
    parameters.zeta = 15.0;

    %Setup the initial values
    settings.F_h_p_0_iv =  @(p, s) 0.1167495;    
    settings.g_iv = @(p, s) 0.02;
    settings.w_h_l_multiplier_iv = @(p, s) .88;    
    settings.F_h_bar_iv = @(p, s) 1/(p.lambda_l + p.lambda_h)*(p.lambda_l - s.g_iv(p, s) * s.F_h_p_0_iv(p,s));
    settings.F_l_iv = @(z, p, s) z/p.z_bar * (1 - s.F_h_bar_iv(p, s));
    settings.F_h_iv = @(z, p, s) z/p.z_bar * s.F_h_bar_iv(p, s);
    settings.w_h_iv = @(z, p, s) 2 * s.g_iv(p, s) / p.chi / p.z_bar * z;
    settings.w_l_iv = @(z, p, s) 2 * s.g_iv(p, s) / p.chi / p.z_bar * z * s.w_h_l_multiplier_iv(p, s); 
    settings.f_l_iv = @(z, p, s) 1/p.z_bar * (1 - s.F_h_bar_iv(p, s))+ 0.0 *z;
    settings.f_h_iv = @(z, p, s) 1/p.z_bar * s.F_h_bar_iv(p, s) + 0.0 *z;
    
    %%Settings
    settings.print_level = 0;
    settings.debug_output = 0;
    settings.relative_tolerance = 1E-9; %parameter used by solvers.
    settings.convergence_tolerance = 5E-3; %resnorm check
    settings.collocation_nodes = 60;
    settings.max_iterations = 100;
    settings.alpha_tail_proportion = 0.9;
    settings.calculate_interpolation = true;

    %Settings focused on constraints
    settings.F_monotonicity_threshold = -1E-4;
    settings.F_tolerance = 1E-3;
    settings.interpolator = @(grid, values) griddedInterpolant(grid, values, 'spline','nearest');
    settings.stop_if_not_converged = true;
    
    %Settings for finding the maximum g
    settings.UseParallel = true;
    settings.Algorithm = 'trust-region-reflective';
    settings.upweight_F_bar = 5.0;
    settings.upweight_F_1 = 2.0;
    settings.Display = 'off';
end

