init_lib(); %Initialize the library, clearing the screen, etc.
set_output_figure_defaults(); %sets line thickness, etc.
figure_width = 600;
figure_height = 200;   

%% Example Settings and parameters
[p, s] = baseline_joint_endogenous_settings(); %loads baseline settings and parameters. All can then be modified

%Parameters (changed from the baseline)
p.lambda_l = 0.533074;
p.lambda_h = 1.12766;
p.chi = 0.001074;
p.psi = 1;
p.Lambda = 1;
p.rho = .01;
p.eta = 0;
p.varsigma = 0;
p.vartheta = 0;
p.theta_bar = 0;
p.kappa_bar = 1;
p.zeta = 27.2;
p.z_bar = 4;

plot_figure_10 = true;
plot_figure_11 = true;
plot_figure_12 = true;

%% Single example
if(plot_figure_10)
    figure_file_name = 'figure_10.pdf';
   
    [g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged, residual] = solve_joint_endogenous(p, s);
    display_s('residual = %d, g = %f', residual, g);

    %Plots for the paper
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width figure_height]); %for legend: 0 occludes as little as possible, 1 is rh corner, then counter clockwise.
    subplot(1,2,1);
    plot(grids.z_vec, grids.gamma_grid);
    xlabel('$z$');
    leg = legend('$\gamma(z)$');
    leg.Location = 'southeast';
    ylim([0 max(grids.gamma_grid)]);
    subplot(1,2,2);
    plot(grids.z_vec, grids.F_l_p_grid, grids.z_vec, grids.F_h_p_grid, '--');
    xlabel('$z$');
    leg = legend("$F'_{\ell}(z)$","$F'_h(z)$");
    leg.Location = 'northeast';
    ylim([0 max(grids.F_l_p_grid)]);
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');
end

%% Plot the role of excludability
if(plot_figure_11)
    figure_file_name = 'figure_11.pdf';
   
    old_p = p;
    old_s = s;
    psi_grid = 0.13:.02:1.0;
    g_psi_grid = NaN(1,length(psi_grid));
    gini_psi_grid = NaN(1,length(psi_grid));
    
    for i=1:length(psi_grid)
        p.psi = psi_grid(i);
        [g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged, residual] = solve_joint_endogenous(p, s);        
        if(converged)
            display_s('residual = %d, g = %f', residual, g);
            g_psi_grid(i) = g;
            gini_psi_grid(i) = distribution_shape.gini;
            %Use this solution for the IV next time
            s.F_l_iv = @(z, p, s) F_l(z);
            s.F_h_iv = @(z, p, s) F_h(z);
            s.w_l_iv = @(z, p, s) w_l(z);
            s.w_h_iv = @(z, p, s) w_h(z);
        else
            display_s('No convergence.  residual = %d, g = %f', residual, g);            
        end
    end
    
    psi_display_grid = 1:length(psi_grid);

    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width figure_height]);
    subplot(1,2,1);    
    plot(psi_grid(psi_display_grid), g_psi_grid(psi_display_grid));
    xlabel('$\psi$');
    ylim([0.02, 0.0325]);
    leg = legend('$g$');
    leg.Location = 'northeast';
    
    subplot(1,2,2);    
    plot(psi_grid(psi_display_grid), gini_psi_grid(psi_display_grid));
    xlabel('$\psi$');
    ylim([0.425, 0.475]);    
    leg = legend('Gini');
    leg.Location = 'east';
    
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');
    
    p = old_p;
    s = old_s;
end

%% Plot zeta and growth rates given various psi
if(plot_figure_12)
    figure_file_name = 'figure_12.pdf';
    old_p = p;
    old_s = s;
    
    psi_grid = 0.6:.2:1.0;
    %zeta_grid = 20:.1:32;
    zeta_grid = 4:1:40;
    
    for i=1:length(psi_grid)
        for j=1:length(zeta_grid)
            p.zeta = zeta_grid(j);
            p.psi = psi_grid(i);
            [g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged, residual] = solve_joint_endogenous(p, s);
            if(converged)
                display_s('residual = %d, g = %f', residual, g);
                
                g_psi_zeta_grid(i,j) = g;
                gini_psi_zeta_grid(i,j) = distribution_shape.gini;
                s.F_l_iv = @(z, p, s) F_l(z);
                s.F_h_iv = @(z, p, s) F_h(z);
                s.w_l_iv = @(z, p, s) w_l(z);
                s.w_h_iv = @(z, p, s) w_h(z);
            end
        end
    end
    zeta_display_grid = 3:length(zeta_grid);
    
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width figure_height]);
    subplot(1,2,1);      
    plot(zeta_grid(zeta_display_grid), g_psi_zeta_grid(1,zeta_display_grid),zeta_grid(zeta_display_grid), g_psi_zeta_grid(2,zeta_display_grid), '--', zeta_grid(zeta_display_grid), g_psi_zeta_grid(3,zeta_display_grid), ':');
    xlabel('$\zeta$');
    leg = legend('$g(\psi = 0.6)$','$g(\psi = 0.8)$','$g(\psi = 1.0)$');
    ylim([.018 0.04]);
    leg.Box = true;
    leg.Location = 'northeast';

    subplot(1,2,2);      
    plot(zeta_grid(zeta_display_grid), gini_psi_zeta_grid(1,zeta_display_grid),zeta_grid(zeta_display_grid), gini_psi_zeta_grid(2,zeta_display_grid), '--', zeta_grid(zeta_display_grid), gini_psi_zeta_grid(3,zeta_display_grid), ':');
    xlabel('$\zeta$');
    leg = legend('Gini$(\psi = 0.6)$','Gini$(\psi = 0.8)$','Gini$(\psi = 1.0)$');
    ylim([0.465 0.49]);
    leg.Box = true;
    leg.Location = 'northeast';
    
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');    
    
    p = old_p;
    s = old_s;
end



