function figures_4_5()
    init_lib(); % clear everything
    set_output_figure_defaults(); %sets line thickness, etc.
    figure_width = 600;
    figure_height = 200;    

    %Parameter Values
    params.zeta = 25.18;
    params.gamma = .02;
    rho = .01;
    params.r  = rho + params.gamma; % use log utility
    params.eta = 0.00098;
    params.lambda_l = 0.533074;
    params.lambda_h = 1.12766;
    settings.S_root_bounds = [.0001 30];


    figure_file_name = 'figure_4.pdf';    
    [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings);
    display_s('z_bar: %f, alpha: %f',z_bar, alpha);

    z_grid = 0:.01:z_bar;
    v_l_grid = arrayfun(@(z) v_l(z), z_grid);
    v_h_grid = arrayfun(@(z) v_h(z), z_grid);
    f_l_grid = arrayfun(@(z) f_l(z), z_grid);
    f_h_grid = arrayfun(@(z) f_h(z), z_grid);
    
    % Plot results
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width figure_height]);
    subplot(1,2,1);
    plot(z_grid, v_l_grid, z_grid, v_h_grid, '--');
    xlabel('$z$');
    yticks(100:50:250)
    ylim([100, 250.0])
    leg = legend('$v_{\ell}(z)$','$v_h(z)$');    
    leg.Location = 'northwest';
    xlim([0 z_bar]);
    
    subplot(1,2,2); plot(z_grid, f_l_grid, z_grid, f_h_grid, '--');
    xlabel('$z$');
    xlim([0 z_bar]);    
    leg = legend("$F'_{\ell}(z)$","$F'_h(z)$");
    yticks(0.0:0.5:1.5)
    ylim([0.0, 1.5])
    leg.Location = 'northeast';
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');    
    
    %% Comparative statics on z_bar and alpha
    %% Generate Figure 5
    old_params = params; %save before changing
    figure_file_name = 'figure_5.pdf';
    
    eta_grid = .0001:.0001: .02;
    for i=1:length(eta_grid)
        params.eta = eta_grid(i);
        [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings);
        alpha_eta_grid(i) = alpha;
        z_bar_eta_grid(i) = z_bar;
    end
    
    params = old_params;
    gamma_grid = .01:.001:.03;
    for i=1:length(gamma_grid)
        params.gamma = gamma_grid(i);
        params.r  = rho + params.gamma; % use log utility
        [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings);
        alpha_gamma_grid(i) = alpha;
        z_bar_gamma_grid(i) = z_bar;
    end
    
    params = old_params;
    zeta_grid = 15:.01:25;
    for i=1:length(zeta_grid)
        params.zeta = zeta_grid(i);
        [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings);
        alpha_zeta_grid(i) = alpha;
        z_bar_zeta_grid(i) = z_bar;
    end

    params = old_params;
    lambda_h_grid = .5:.01:2.0;
    for i=1:length(lambda_h_grid)
        params.lambda_h = lambda_h_grid(i);
        [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings);
        alpha_lambda_h_grid(i) = alpha;
        z_bar_lambda_h_grid(i) = z_bar;
    end

    % Plot results
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width (2*figure_height)]);
    subplot(2,2,1);
    [ax,p1,p2] = plotyy(eta_grid, z_bar_eta_grid, eta_grid, alpha_eta_grid, 'plot', 'plot');
    xlabel('$\eta$');
    leg = legend('$\bar{z}$','$\alpha$');
    leg.Location = 'northeast';
    set(ax(1),'XLim',[min(eta_grid) max(eta_grid)]);
    set(ax(2),'XLim',[min(eta_grid) max(eta_grid)]);
    p2.LineStyle = '--';

    subplot(2,2,2);
    [ax,p1,p2] = plotyy(gamma_grid, z_bar_gamma_grid, gamma_grid, alpha_gamma_grid, 'plot', 'plot');
    xlabel('$\gamma$');
    leg = legend('$\bar{z}$','$\alpha$');
    leg.Location = 'south';
    set(ax(1),'XLim',[min(gamma_grid) max(gamma_grid)]);
    set(ax(2),'XLim',[min(gamma_grid) max(gamma_grid)]);
    p2.LineStyle = '--';
    
    subplot(2,2,3);
    [ax,p1,p2] = plotyy(zeta_grid, z_bar_zeta_grid, zeta_grid, alpha_zeta_grid, 'plot', 'plot');
    xlabel('$\zeta$');
    leg = legend('$\bar{z}$','$\alpha$');
    leg.Location = 'north';
    set(ax(1),'XLim',[min(zeta_grid) max(zeta_grid)]);
    set(ax(2),'XLim',[min(zeta_grid) max(zeta_grid)]);
    p2.LineStyle = '--';
    
    subplot(2,2,4);
    [ax,p1,p2] = plotyy(lambda_h_grid, z_bar_lambda_h_grid, lambda_h_grid, alpha_lambda_h_grid, 'plot', 'plot');
    xlabel('$\lambda_h$');
    leg = legend('$\bar{z}$','$\alpha$');
    leg.Location = 'north';
    set(ax(1),'XLim',[min(lambda_h_grid) max(lambda_h_grid)]);
    set(ax(2),'XLim',[min(lambda_h_grid) max(lambda_h_grid)]);
    p2.LineStyle = '--';
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');            
end

% Algebraic solution
function [alpha, z_bar, F_l, f_l, F_h, f_h, v_l, v_h] = solve_bounded_exogenous(params, settings)
    r = params.r;
    zeta = params.zeta;
    gamma = params.gamma;
    eta = params.eta;
    lambda_l = params.lambda_l;
    lambda_h = params.lambda_h;

    % Implicit function simplified using mathematica
    S_root = @(S) (r+(-1).*gamma).^(-1)+zeta+(-1).*S.*gamma.^(-2).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+(eta+lambda_h).^(-1).*lambda_l).*(1+gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).^(-1).*(gamma.*((-1).*r+gamma).^(-1).*(S+(-1).*eta).^(-1).*(S.*eta.^(-1)).^(gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*eta.*((-1)+S.^(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)+(-1).*(r+(-1).*gamma).^(-1).*gamma.^2.*(S+(-1).*eta).^(-1).*(S.*eta.^(-1)).^((S+(-1).*eta).^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*eta.*(r+(-1).*gamma+eta).^(-1).*((-1)+S.^(-1).*eta).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)+(1+(-1).*S.^(-1).*(S.*eta.^(-1)).^(gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*eta).*((-1)+gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).^(-1)+gamma.*(1+(-1).*(S.*eta.^(-1)).^((-1).*gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1).*(gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)+gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)))).*(r+(-1).*gamma+eta).^(-1).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1).*(gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)+gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).^(-1));
    
    %Need to ensure the root is bracketed
    S_root_bounds = settings.S_root_bounds;
    if(isnan(S_root(S_root_bounds(1))))
        S_root_bounds(1) = S_root_bounds(1) * 10; %Upper bound rarely a problem, but can expand it
    end

    %Find the S
    S = fzero(S_root, S_root_bounds);
    assert(S > 0);

    z_bar = gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1).*log(S.*eta.^(-1));
    alpha = gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l);
    f_h = @(z) exp(1).^((-1).*z.*gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).*S.*gamma.^(-1).*(eta+lambda_h).^(-1).*lambda_l;
    F_h = @(z) (S+(-1).*exp(1).^((-1).*z.*gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).*S).*(S+(-1).*eta).^(-1).*(eta+lambda_h).^(-1).*lambda_l.*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1);
    f_l = @(z) exp(1).^((-1).*z.*gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).*S.*gamma.^(-1);
    F_l = @(z) (S+(-1).*exp(1).^((-1).*z.*gamma.^(-1).*(S+(-1).*eta).*(1+(eta+lambda_h).^(-1).*lambda_l)).*S).*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1);
    v_h = @(z) (r+(-1).*gamma+lambda_h).^(-1).*(exp(1).^z+gamma.^(-1).*(r+(-1).*gamma+lambda_h).^(-1).*((-1).*eta+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).^(-1).*(exp(1).^z+exp(1).^(z.*gamma.^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).*gamma.*(r+(-1).*gamma+eta).^(-1).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1)+(r+(-1).*gamma).^(-1).*eta.*((S.*eta.^(-1)).^(gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1))+gamma.*(S.*eta.^(-1)).^((S+(-1).*eta).^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*(r+(-1).*gamma+eta).^(-1).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1)))+eta.*(1+(-1).*((-1).*r+gamma).^(-1).*eta).*((S.*eta.^(-1)).^(gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(gamma+(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).^(-1)+(S.*eta.^(-1)).^((S+(-1).*eta).^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*(r+(-1).*gamma+eta).^(-1).*(1+gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).^(-1)));
    v_l = @(z) gamma.^(-1).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+gamma.^(-1).*(r+(-1).*gamma+eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).^(-1).*(exp(1).^z+exp(1).^(z.*gamma.^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l)).*gamma.*(r+(-1).*gamma+eta).^(-1).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1)+(r+(-1).*gamma).^(-1).*eta.*((S.*eta.^(-1)).^(gamma.*(S+(-1).*eta).^(-1).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1))+gamma.*(S.*eta.^(-1)).^((S+(-1).*eta).^(-1).*((-1).*r+gamma+(-1).*eta).*(r+(-1).*gamma+lambda_h).^(-1).*(r+(-1).*gamma+lambda_h+lambda_l).*(1+(eta+lambda_h).^(-1).*lambda_l).^(-1)).*(r+(-1).*gamma+eta).^(-1).*(r+(-1).*gamma+lambda_h).*(r+(-1).*gamma+lambda_h+lambda_l).^(-1)));
    assert(z_bar > 0);
    assert(alpha > 0);    
end
