init_lib();  %Initialize the library, clearing the screen, etc.
set_output_figure_defaults(); %sets line thickness, etc.
figure_width = 600;
figure_height = 200;    

%% Example Settings and parameters
[p, s] = baseline_joint_endogenous_settings(); %loads baseline settings and parameters. All can then be modified
%Parameters
p.lambda_l = 0.533074;
p.lambda_h = 1.12766;
p.chi = 0.00115;
p.psi = .95;
p.Lambda = 1;
p.rho = .01;
p.eta = 0.00098;
p.zeta = 25.18;
p.z_bar = 1.61;

%Settings
s.debug_output = 0;

calculate_figure_6 = true;
calculate_figure_7 = true;
calculate_figure_8 = true;

if(calculate_figure_6)
    figure_file_name = 'figure_6.pdf';
    
    %Solve using these values
    tic;
    [g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged, residual] = solve_joint_endogenous(p, s);
    toc;
    if(converged)
        display_s('residual = %d, g = %f\n', residual, g);

        %Clean up some of the noise in the display
        grids.F_h_p_grid(grids.F_h_p_grid > .5) = NaN;
        grids.F_l_p_grid(grids.F_l_p_grid < 0) = NaN;

        output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width figure_height]); 
        subplot(1,2,1);
        plot(grids.z_vec, grids.gamma_grid);
        xlabel('$z$');
        leg = legend('$\gamma(z)$');
        leg.Location = 'northwest';
        ylim([0 max(grids.gamma_grid)]); 

        subplot(1,2,2);
        plot(grids.z_vec, grids.F_l_p_grid, grids.z_vec, grids.F_h_p_grid, '--');
        xlabel('$z$');
        leg = legend("$F'_{\ell}(z)$","$F'_h(z)$");
        leg.Location = 'northeast';
        p2.LineStyle = '--';
        ylim([0 max(grids.F_l_p_grid)]); 
        exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');            
    else
        display_s('No convergence residual norm = %d\n', residual);
    end
end

if(calculate_figure_7)
    p_old = p;
    s_old = s;
    
    figure_file_name = 'figure_7.pdf';
    z_bar_grid = 0.8:.1:3;
    for i=1:length(z_bar_grid)
        p.z_bar = z_bar_grid(i);
        [g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged, residual] = solve_joint_endogenous(p, s);
        if(converged)
            display_s('psi = %f, residual = %d, g = %f',p.psi,residual, g);
            g_z_bar_grid(i) = g;
            gini_grid(i) = distribution_shape.gini;
            %Use this solution for the IV next time
            s.F_l_iv = @(z, p, s) F_l(z);
            s.F_h_iv = @(z, p, s) F_h(z);
            s.w_l_iv = @(z, p, s) w_l(z);
            s.w_h_iv = @(z, p, s) w_h(z);
        else
            g_z_bar_grid(i) = NaN;
            gini_grid(i) = NaN;
        end
    end
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width/2 figure_height]); 
    plot(z_bar_grid,g_z_bar_grid);
    xlabel('$\bar{z}$');
    ylim([0.019, 0.021]);
    leg = legend('$g(\bar{z})$');
    leg.Location = 'southeast';

    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');    
        
    final_p = p;
    final_s = s;
    p = p_old;
    s = s_old;
    
end


if(calculate_figure_8)
    figure_file_name = 'figure_8.pdf';
    eta_grid = linspace(0.0001, 0.02, 30);
    g_eta_max = NaN(1,length(eta_grid));
    z_bar_eta_max= NaN(1,length(eta_grid));
    gini_eta_max = NaN(1,length(eta_grid));

    for i=1:length(eta_grid)
        p.eta = eta_grid(i);
        z_bar_range = linspace(1.1, 3.2, 120);
        [max_z_bar, min_z_bar, g_max, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged] = solve_joint_endogenous_max_g(p, s, z_bar_range);
        if(converged)
            display_s('MAX: eta = %f, max_z_bar = %f, g = %f',p.eta, max_z_bar, g_max);
            z_bar_eta_max(i) = max_z_bar;
            g_eta_max(i) = g_max;
            gini_eta_max(i) = distribution_shape.gini;
            %Use this solution for the IV next time
            s.F_l_iv = @(z, p, s) F_l(z);
            s.F_h_iv = @(z, p, s) F_h(z);
            s.w_l_iv = @(z, p, s) w_l(z);
            s.w_h_iv = @(z, p, s) w_h(z);            
            s.x_iv = grids.x_sol;            
        else
            display_s('No convergence for eta = %f', p.eta);
            break;
        end
    end
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width/2 figure_height]);
    plot(eta_grid,g_eta_max);
    xlabel('$\eta$');
    leg = legend('$\max g(\eta)$');
    xlim([0.0, 0.021]);
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');    
end