init_lib();  %Initialize the library, clearing the screen, etc.
set_output_figure_defaults(); %sets line thickness, etc.
figure_width = 600;
figure_height = 200;    

[p, s] = baseline_joint_endogenous_settings(); %loads baseline settings and parameters. All can then be modified
p.lambda_l = 0.533074;
p.lambda_h = 1.12766;
p.chi = 0.00115;
p.psi = 1.0;
p.Lambda = 1;
p.rho = .01;
p.zeta = 25.18;
p.z_bar = 1.61;

% Tightening threshold.  These plots are more sensitive to monotonicity since we explore a wide range of values
s.F_monotonicity_threshold = -1E-6;

% Plots
eta_medium = 0.01;
eta_small = 0.001;

plot_figure_9 = true;
plot_figure_13 = true;

if(plot_figure_9)
    zeta_grid = linspace(4, 40, 30);
    z_bar_range = linspace(0.6, 2, 100);
    z_bar_range_small = linspace(2, 4.5, 100);

    figure_file_name = 'figure_9.pdf';    
    p_old = p;
    s_old = s;
    p.psi = 1.0;

    p.eta = eta_medium;
    g_zeta_max = NaN(1,length(zeta_grid));
    gini_zeta_max = NaN(1,length(zeta_grid));
    z_bar_zeta_max = NaN(1,length(zeta_grid));
    
    for i=1:length(zeta_grid)
        p.zeta = zeta_grid(i);
        [max_z_bar, min_z_bar, g_max, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged] = solve_joint_endogenous_max_g(p, s, z_bar_range);
        if(converged)
            display_s('zeta = %f, eta = %f, max_g = %f, max_z_bar = %f, min z_bar = %f',p.zeta, p.eta, g_max, max_z_bar, min_z_bar);
            %Use this solution for the IV next time
            s.F_l_iv = @(z, p, s) F_l(z);
            s.F_h_iv = @(z, p, s) F_h(z);
            s.w_l_iv = @(z, p, s) w_l(z);
            s.w_h_iv = @(z, p, s) w_h(z);            
            g_zeta_max(i) = g_max;
            z_bar_zeta_max(i) = max_z_bar;
            gini_zeta_max(i) = distribution_shape.gini;
        else
            display_s('No solution found for zeta = %f, eta = %f', p.zeta, p.eta)
        end
    end

    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width/2 figure_height]);     
    plot(zeta_grid, g_zeta_max);
    xlabel('$\zeta$');
    ylim([0.015, 0.017]);
    yyaxis right;
    plot(zeta_grid, z_bar_zeta_max, '--');
    ylim([0.5, 2]);    
    leg = legend('$\max g$','$\bar{z}$');    
    leg.Location = 'northwest';
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');            
    
    p = p_old;
    s = s_old;
end

if(plot_figure_13)
    figure_file_name = 'figure_13.pdf';           
    p_old = p;
    s_old = s;

    p.psi = 0.5;
    p.eta = eta_medium;

    z_bar_range = linspace(1.1, 2.5, 100);
    zeta_grid = linspace(4, 40, 30);

    g_zeta_max = NaN(1,length(zeta_grid));
    gini_zeta_max = NaN(1,length(zeta_grid));
    z_bar_zeta_max = NaN(1,length(zeta_grid));

    for i=1:length(zeta_grid)
        p.zeta = zeta_grid(i);
        [max_z_bar, min_z_bar, g_max, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged] = solve_joint_endogenous_max_g(p, s, z_bar_range);
        if(converged)
            display_s('zeta = %f, eta = %f, max_g = %f, max_z_bar = %f, min z_bar = %f',p.zeta, p.eta, g_max, max_z_bar, min_z_bar);
            %Use this solution for the IV next time
            s.F_l_iv = @(z, p, s) F_l(z);
            s.F_h_iv = @(z, p, s) F_h(z);
            s.w_l_iv = @(z, p, s) w_l(z);
            s.w_h_iv = @(z, p, s) w_h(z);            
            g_zeta_max(i) = g_max;
            z_bar_zeta_max(i) = max_z_bar;
            gini_zeta_max(i) = distribution_shape.gini;
        else
            display_s('No solution found for zeta = %f, eta = %f', p.zeta, p.eta)
        end
    end
    
    output_figure = figure('Name','','NumberTitle','off', 'Position', [0 0 figure_width/2 figure_height]); 
    plot(zeta_grid, g_zeta_max);
    xlabel('$\zeta$');
    yyaxis right;
    plot(zeta_grid, z_bar_zeta_max, '--');
    leg = legend('$\max g$','$\bar{z}$');    
    leg.Location = 'east';
    exportgraphics(output_figure, figure_file_name,'BackgroundColor','none','ContentType','vector');

    p = p_old;
    s = s_old;
end