% Calculates the joint-residuals for the system with endogenous investment
function residual = joint_endogenous_L(x, p, s)
    lambda_l = p.lambda_l;
    lambda_h = p.lambda_h;
    chi = p.chi;
    psi = p.psi;
    eta = p.eta;
    zeta = p.zeta;
    rho = p.rho;
    Lambda = p.Lambda;
    N = s.N;
    
    %Unpack the basis parameters for w_l, w_h, F_l, and F_h in that order
    c_l = x(1:N);
    c_h = x(N+1:2*N);
    d_l = x(2*N+1:3*N);
    d_h = x(3*N+1:4*N);
    
    %Calculate the functions from the basis
    w_l = s.B * c_l;
    w_h = s.B * c_h;
    w_l_p = s.B_p * c_l;
    w_h_p = s.B_p * c_h;
    F_l = s.B * d_l;
    F_h = s.B * d_h;
    F_l_p = s.B_p * d_l;
    F_h_p = s.B_p * d_h;
    
    %Calculations prior to residual
    g = w_h(end) * chi/2;
    r = rho + g * Lambda;
    F_l_p_0 = F_l_p(1);
    F_h_p_0 = F_h_p(1);
    F_p_0 = F_l_p_0 + F_h_p_0;
    F = F_l + F_h;
    w_tilde_l = w_l .* s.exp_z_vec; % combining terms for the quadrature in the value matching
    upgrade_cost = 1/psi *zeta;
    
    %Residual construction.  Stacks the KFE and HJBE, with boundary conditions, and the value matching condition
    residual(1:N+2) =  1 -(r + lambda_l + eta - (1-psi)*g*F_p_0) * w_l - g * w_l_p + lambda_l * w_h;
    residual(N+3:2*N+4) = 1 -(r + lambda_h + eta) * w_h  - (g - chi/2 * w_h).* w_h_p + (lambda_h +(1-psi)*g*F_p_0) * w_l + chi/4 * w_h.^2;
    residual(2*N+5:3*N+6) = g * F_l_p + lambda_h * F_h - (lambda_l + eta)* F_l + g * F_p_0 * F - g * F_l_p_0;
    residual(3*N+7:4*N+8) =  (g - w_h * chi/2) .* F_h_p + lambda_l * F_l - (lambda_h + eta) * F_h - g * F_h_p_0;
    residual(4*N+9) = s.upweight_F_1 * F_l(1);  % can upweight to make sure that F_l(0) = 0 is more important to residuals
    residual(4*N+10) = s.upweight_F_1 * F_h(1);
    residual(4*N+11) = w_l(1);
    residual(4*N+12) = w_h(1);
    residual(4*N+13) = -upgrade_cost + s.omega * w_tilde_l(2:N+1) - s.omega * (w_tilde_l(2:N+1) .* F(2:N+1));
    residual(4*N+14) = s.upweight_F_bar * (F(end) - 1); % can upweight to ensure F(1) = 1 is more important to the minimization.
end
 
