% Compute the equilibrium repeatedly, increasing z_bar to find the maximum g

function[max_z_bar, min_z_bar, g, w_l, w_h, gamma, F_l, F_h, F, f_l, f_h, f, distribution_shape, derivatives, grids, result, converged] = solve_joint_endogenous_max_g(p, s, z_bar_range)
    converged = false;
    g=NaN; w_l=NaN; w_h=NaN; gamma=NaN; F_l=NaN; F_h=NaN; F=NaN; distribution_shape.EMPTY=NaN; derivatives.EMPTY=NaN; grids.EMPTY=NaN; f_l = NaN; f_h = NaN; f = NaN;
    min_z_bar = NaN;
    
    % increase 
    for i=1:length(z_bar_range)
        p.z_bar = z_bar_range(i);
        [g_i, w_l_i, w_h_i, gamma_i, F_l_i, F_h_i, F_i, f_l_i, f_h_i, f_i, distribution_shape_i, derivatives_i, grids_i, result_i, converged_i, residual_i] = solve_joint_endogenous(p, s);

        % Only update if it converged
        if converged_i
            if s.debug_output
                display_s('residual = %d, g = %f, z_bar = %f', residual_i, g_i, p.z_bar);
            end
            if isnan(g)
                min_z_bar = p.z_bar;
            end
            g = g_i; w_l = w_l_i; w_h = w_h_i; gamma = gamma_i; F_l = F_l_i; F_h = F_h_i; F = F_i; f_l = f_l_i; f_h = f_h_i; f = f_i;
            distribution_shape = distribution_shape_i; derivatives = derivatives_i; grids = grids_i; result = result_i; converged = converged_i;

           %Change the initial condition to speed up convergence of next step
           s.F_l_iv = @(z, p, s) F_l(z);
           s.F_h_iv = @(z, p, s) F_h(z);
           s.w_l_iv = @(z, p, s) w_l(z);
           s.w_h_iv = @(z, p, s) w_h(z);
           max_z_bar = p.z_bar;
           if s.debug_output
               display_s('z_bar = %f, g = %f',  max_z_bar, g);
           end          
        else                
           if s.debug_output
                display_s('z_bar = %f did not converge',  p.z_bar);
           end
            if ~isnan(g) && s.stop_if_not_converged
                break;
            end
        end
    end
    
    %If not a solution at this point, nothing feasible has been found
    if isnan(min_z_bar)
        max_z_bar = NaN;
        result = NaN;
        display_s('No solution found');
        return;
    end

end
